@@ -75,6 +75,12 @@ UDPSyslogger::setNameWithoutUpdate(char* name)
     strncpy(name_, name, sizeof(name_)   - 1);
 }
 
+void
+UDPSyslogger::setPidWithoutUpdate(int pid)
+{
+    pid_ = pid;
+}
+
 void
 UDPSyslogger::updatePrefix(time_t t) {
     last_time_ = t;
